@@ -7,7 +7,7 @@ from qase.api_client_v1.configuration import Configuration
 from .. import Logger
 from .base_api_client import BaseApiClient
 from ..exceptions.reporter import ReporterException
-from ..models import Attachment, Result, Step
+from ..models import Attachment, InternalResult, Step
 from ..models.config.framework import Video, Trace
 from ..models.config.qaseconfig import QaseConfig
 from ..models.step import StepType
@@ -134,7 +134,7 @@ class ApiV1Client(BaseApiClient):
         )
         self.logger.log_debug(f"Results for run {run_id} sent successfully")
 
-    def _prepare_result(self, project_code: str, result: Result) -> Dict:
+    def _prepare_result(self, project_code: str, result: InternalResult) -> Dict:
         attached = []
         if result.attachments:
             for attachment in result.attachments:
